DimensionNames

Trait DimensionNames 

pub trait DimensionNames {
    // Required method
    fn names(&self) -> [Dimension; 2];
}
The first and second dimension name a Matrix type wrapped in a TensorRefMatrix will report on its view shape. If you don’t care what the dimension names are, RowAndColumn can be used which will hardcode the dimension names to “row” and “column” respectively.

Required Methods

fn names(&self) -> [Dimension; 2]

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl DimensionNames for [Dimension; 2]

Any array of two dimension names will implement DimensionNames returning those names in the same order.

Source

fn names(&self) -> [Dimension; 2]

Implementors