Struct easy_ml::linear_algebra::QRDecomposition [−][src]
The result of a QR Decomposition of some matrix A such that QR = A.
Fields
q: Matrix<T>r: Matrix<T>Implementations
impl<T> QRDecomposition<T>[src]
impl<T> QRDecomposition<T>[src]pub fn from_unchecked(q: Matrix<T>, r: Matrix<T>) -> QRDecomposition<T>[src]
pub fn from_unchecked(q: Matrix<T>, r: Matrix<T>) -> QRDecomposition<T>[src]Creates a QR Decomposition struct from two matrices without checking that QR = A or that Q and R have the intended properties.
This is provided for assistance with unit testing.