Struct easy_ml::matrices::slices::ColumnSlice2DBuilder[][src]

pub struct ColumnSlice2DBuilder { /* fields omitted */ }

A builder object to create a slice. This exists to make forgetting to specify rows and columns a compilation error rather than a runtime one.

Implementations

impl ColumnSlice2DBuilder[src]

pub fn rows(self, rows: Slice) -> Slice2D[src]

Constructs a 2d slice with rows and columns defined.