Struct easy_ml::matrices::slices::EmptySlice2DBuilder [−][src]
pub struct EmptySlice2DBuilder {}A builder object to create a slice. This exists to make forgetting to specify rows and columns a compilation error rather than a runtime one.
Implementations
impl EmptySlice2DBuilder[src]
impl EmptySlice2DBuilder[src]pub fn rows(self, rows: Slice) -> RowSlice2DBuilder[src]
pub fn rows(self, rows: Slice) -> RowSlice2DBuilder[src]Constructs a new builder object with the rows defined first.
pub fn columns(self, columns: Slice) -> ColumnSlice2DBuilder[src]
pub fn columns(self, columns: Slice) -> ColumnSlice2DBuilder[src]Constructs a new builder object with the columns defined first.