IndexRange

Struct IndexRange 

pub struct IndexRange { /* private fields */ }
A range bounded between start inclusive and start + length exclusive.

Examples

Converting between Range and IndexRange.

use std::ops::Range;
use easy_ml::matrices::views::IndexRange;
assert_eq!(IndexRange::new(3, 2), (3..5).into());
assert_eq!(IndexRange::new(1, 5), (1..6).into());
assert_eq!(IndexRange::new(0, 4), (0..4).into());

Creating a Range

use easy_ml::matrices::views::IndexRange;
let range = IndexRange::new(3, 2);
let also_range: IndexRange = (3, 2).into();
let also_also_range: IndexRange = [3, 2].into();

NB: You can construct an IndexRange where start+length exceeds isize::MAX or even usize::MAX, however matrices and tensors themselves cannot contain more than isize::MAX elements. Concerned readers should note that on a 64 bit computer this maximum value is 9,223,372,036,854,775,807 so running out of memory is likely to occur first.

Implementations

Source

impl IndexRange

pub fn new(start: usize, length: usize) -> IndexRange