pub unsafe trait MatrixMut<T>: MatrixRef<T> {
// Required methods
fn try_get_reference_mut(
&mut self,
row: Row,
column: Column,
) -> Option<&mut T>;
unsafe fn get_reference_unchecked_mut(
&mut self,
row: Row,
column: Column,
) -> &mut T;
}Expand description
Required Methods
Sourcefn try_get_reference_mut(&mut self, row: Row, column: Column) -> Option<&mut T>
fn try_get_reference_mut(&mut self, row: Row, column: Column) -> Option<&mut T>
Gets a mutable reference to the value at the index, if the index is in range. Otherwise returns None.
Sourceunsafe fn get_reference_unchecked_mut(
&mut self,
row: Row,
column: Column,
) -> &mut T
unsafe fn get_reference_unchecked_mut( &mut self, row: Row, column: Column, ) -> &mut T
Gets a mutable reference to the value at the index without doing any bounds checking. For a safe alternative see try_get_reference_mut.
Safety
Calling this method with an out-of-bounds index is undefined behavior even if the resulting reference is not used. Valid indexes are defined as in MatrixRef.