pub trait Sin {
type Output;
// Required method
fn sin(self) -> Self::Output;
}Expand description
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Implementors
Sourceimpl<'a, T, S, const D: usize> Sin for &RecordTensor<'a, T, S, D>
Operation for a referenced record tensor of some type.
impl<'a, T, S, const D: usize> Sin for &RecordTensor<'a, T, S, D>
Operation for a referenced record tensor of some type.
type Output = RecordContainer<'a, T, TensorView<(T, usize), Tensor<(T, usize), D>, D>, D>
Sourceimpl<'a, T, S, const D: usize> Sin for RecordTensor<'a, T, S, D>
Operation for a record tensor of some type.
impl<'a, T, S, const D: usize> Sin for RecordTensor<'a, T, S, D>
Operation for a record tensor of some type.
type Output = RecordContainer<'a, T, TensorView<(T, usize), Tensor<(T, usize), D>, D>, D>
Sourceimpl<'a, T, S> Sin for &RecordMatrix<'a, T, S>
Operation for a referenced record matrix of some type.
impl<'a, T, S> Sin for &RecordMatrix<'a, T, S>
Operation for a referenced record matrix of some type.
type Output = RecordContainer<'a, T, MatrixView<(T, usize), Matrix<(T, usize)>>, 2>
Sourceimpl<'a, T, S> Sin for RecordMatrix<'a, T, S>
Operation for a record matrix of some type.
impl<'a, T, S> Sin for RecordMatrix<'a, T, S>
Operation for a record matrix of some type.