pub struct InconsistentDimensionLengthError<const I: usize> {
pub lengths: [Option<usize>; I],
pub dimension: Dimension,
}Expand description
An error indicating the lengths of dimensions with the same
name were inconsistent in the I input tensors.
Fields
lengths: [Option<usize>; I]The lengths of each matching dimension name in each input in the same order as they were passed to the Einsum APIs.
Some inputs may not have this dimension, so will be None.
dimension: DimensionThe dimension name with an inconsistency.